@@ -1,15 +1,15 @@
 import math
 import torch
 
+from torch import Tensor
 from typing import Any
 from typing import Dict
 from typing import List
 from typing import Optional
+from cftool.types import tensor_dict_type
 
 from .protocol import Encoder1DFromPatches
 from .protocol import Encoder2DFromPatches
-from ....types import tensor_dict_type
-from ....protocol import TrainerState
 from ....constants import LATENT_KEY
 from ....modules.blocks import MixedStackedEncoder
 
@@ -18,38 +18,37 @@ from ....modules.blocks import MixedStackedEncoder
 class ViTEncoder(Encoder1DFromPatches):
     def __init__(
         self,
+        *,
         img_size: int,
         patch_size: int,
         in_channels: int,
         latent_dim: int = 384,
         to_patches_type: str = "vanilla",
         to_patches_config: Optional[Dict[str, Any]] = None,
-        *,
         num_layers: int = 12,
         dropout: float = 0.0,
         drop_path_rate: float = 0.0,
         norm_type: Optional[str] = "layer",
         norm_kwargs: Optional[Dict[str, Any]] = None,
-        first_norm: Optional[torch.nn.Module] = None,
+        embedding_norm: Optional[torch.nn.Module] = None,
         residual_after_norm: bool = False,
         feedforward_dim_ratio: float = 4.0,
         attention_kwargs: Optional[Dict[str, Any]] = None,
         feedforward_kwargs: Optional[Dict[str, Any]] = None,
-        reduce_head: bool = True,
-        sequence_pool: bool = False,
         use_head_token: bool = True,
+        head_pooler: Optional[str] = "mean",
         use_positional_encoding: bool = True,
         norm_after_head: bool = False,
         output_dim: Optional[int] = None,
         aux_heads: Optional[List[str]] = None,
     ):
         super().__init__(
-            img_size,
-            patch_size,
-            in_channels,
-            latent_dim,
-            to_patches_type,
-            to_patches_config,
+            img_size=img_size,
+            patch_size=patch_size,
+            in_channels=in_channels,
+            latent_dim=latent_dim,
+            to_patches_type=to_patches_type,
+            to_patches_config=to_patches_config,
         )
         if attention_kwargs is None:
             attention_kwargs = {}
@@ -67,13 +66,13 @@ class ViTEncoder(Encoder1DFromPatches):
             drop_path_rate=drop_path_rate,
             norm_type=norm_type,
             norm_kwargs=norm_kwargs,
-            first_norm=first_norm,
+            embedding_norm=embedding_norm,
             residual_after_norm=residual_after_norm,
             feedforward_dim_ratio=feedforward_dim_ratio,
-            reduce_head=reduce_head,
-            sequence_pool=sequence_pool,
+            head_pooler=head_pooler,
             use_head_token=use_head_token,
             use_positional_encoding=use_positional_encoding,
+            is_vision_positional_encoding=True,
             norm_after_head=norm_after_head,
             aux_heads=aux_heads,
         )
@@ -83,15 +82,9 @@ class ViTEncoder(Encoder1DFromPatches):
             init = (latent_dim**-0.5) * torch.randn(latent_dim, output_dim)
             self.output_projection = torch.nn.Parameter(init)
 
-    def forward(
-        self,
-        batch_idx: int,
-        batch: tensor_dict_type,
-        state: Optional[TrainerState] = None,
-        **kwargs: Any,
-    ) -> tensor_dict_type:
-        rs = super().forward(batch_idx, batch, state, **kwargs)
-        latent = rs[LATENT_KEY]
+    def forward(self, net: Tensor, **kwargs: Any) -> tensor_dict_type:
+        latent = super().forward(net, **kwargs)
+        rs = {LATENT_KEY: latent}
         if self.aux_heads is None:
             if self.output_projection is not None:
                 rs[LATENT_KEY] = latent @ self.output_projection
@@ -105,19 +98,19 @@ class ViTEncoder(Encoder1DFromPatches):
 class ViTEncoder2D(Encoder2DFromPatches):
     def __init__(
         self,
+        *,
         img_size: int,
         patch_size: int,
         in_channels: int,
         latent_channels: int = 384,
         to_patches_type: str = "vanilla",
         to_patches_config: Optional[Dict[str, Any]] = None,
-        *,
         num_layers: int = 12,
         dropout: float = 0.0,
         drop_path_rate: float = 0.0,
         norm_type: Optional[str] = "layer",
         norm_kwargs: Optional[Dict[str, Any]] = None,
-        first_norm: Optional[torch.nn.Module] = None,
+        embedding_norm: Optional[torch.nn.Module] = None,
         residual_after_norm: bool = False,
         feedforward_dim_ratio: float = 4.0,
         attention_kwargs: Optional[Dict[str, Any]] = None,
@@ -126,12 +119,12 @@ class ViTEncoder2D(Encoder2DFromPatches):
         norm_after_head: bool = False,
     ):
         super().__init__(
-            img_size,
-            patch_size,
-            in_channels,
-            latent_channels,
-            to_patches_type,
-            to_patches_config,
+            img_size=img_size,
+            patch_size=patch_size,
+            in_channels=in_channels,
+            latent_channels=latent_channels,
+            to_patches_type=to_patches_type,
+            to_patches_config=to_patches_config,
         )
         if attention_kwargs is None:
             attention_kwargs = {}
@@ -148,29 +141,22 @@ class ViTEncoder2D(Encoder2DFromPatches):
             drop_path_rate=drop_path_rate,
             norm_type=norm_type,
             norm_kwargs=norm_kwargs,
-            first_norm=first_norm,
+            embedding_norm=embedding_norm,
             residual_after_norm=residual_after_norm,
             feedforward_dim_ratio=feedforward_dim_ratio,
-            reduce_head=False,
-            sequence_pool=False,
+            head_pooler=None,
             use_head_token=False,
             use_positional_encoding=use_positional_encoding,
+            is_vision_positional_encoding=True,
             norm_after_head=norm_after_head,
         )
 
-    def forward(
-        self,
-        batch_idx: int,
-        batch: tensor_dict_type,
-        state: Optional[TrainerState] = None,
-        **kwargs: Any,
-    ) -> tensor_dict_type:
-        rs = super().forward(batch_idx, batch, state, **kwargs)
+    def forward(self, net: Tensor, **kwargs: Any) -> Tensor:
+        latent = super().forward(net, **kwargs)
         resolution = int(round(math.sqrt(self.num_patches)))
-        latent = rs[LATENT_KEY]
         latent = latent.view(latent.shape[0], resolution, resolution, -1)
-        rs[LATENT_KEY] = latent.permute(0, 3, 1, 2).contiguous()
-        return rs
+        latent = latent.permute(0, 3, 1, 2).contiguous()
+        return latent
 
 
 __all__ = [
